LastEq

Struct LastEq 

pub struct LastEq<Rows, Cols, Mat>(pub Mat, pub PhantomData<(Rows, Cols)>);
single matrix

Tuple Fields

0: Mat1: PhantomData<(Rows, Cols)>

Implementations

Source

impl<Rows: Shape, Cols: Shape, M: MatIndex<LayoutTransform = MatLayoutTransform, Rows = Rows, Cols = Cols, Index = (Idx<Rows>, Idx<Cols>)>> LastEq<Rows, Cols, M>
where M::Dyn: MatIndex<Rows = usize, Cols = usize, Index = (usize, usize)>,

pub fn for_each(self, f: impl FnMut(<Self as MatIndex>::Item))

applies f to each element of self

pub fn for_each_with_index( self, f: impl FnMut(Idx<Rows>, Idx<Cols>, <Self as MatIndex>::Item), )

applies f to each element of self, while passing the indices of the position of the current element

pub fn for_each_triangular_lower_with_index( self, diag: Diag, f: impl FnMut(Idx<Rows>, Idx<Cols>, <Self as MatIndex>::Item), )

applies f to each element of the lower triangular half of self, while passing the indices of the position of the current element

diag specifies whether the diagonal should be included or excluded

pub fn for_each_triangular_upper_with_index( self, diag: Diag, f: impl FnMut(Idx<Rows>, Idx<Cols>, <Self as MatIndex>::Item), )

applies f to each element of the upper triangular half of self, while passing the indices of the position of the current element

diag specifies whether the diagonal should be included or excluded

pub fn for_each_triangular_lower( self, diag: Diag, f: impl FnMut(<Self as MatIndex>::Item), )

applies f to each element of the lower triangular half of self

diag specifies whether the diagonal should be included or excluded

pub fn for_each_triangular_upper( self, diag: Diag, f: impl FnMut(<Self as MatIndex>::Item), )

applies f to each element of the upper triangular half of self

diag specifies whether the diagonal should be included or excluded

pub fn map<T>( self, f: impl FnMut(<Self as MatIndex>::Item) -> T, ) -> Mat<T, Rows, Cols>

applies f to each element of self and collect its result into a new matrix

pub fn map_with_index<T>( self, f: impl FnMut(Idx<Rows>, Idx<Cols>, <Self as MatIndex>::Item) -> T, ) -> Mat<T, Rows, Cols>

applies f to each element of self and collect its result into a new matrix

Source

impl<Rows: Shape, M: MatIndex<LayoutTransform = VecLayoutTransform, Rows = Rows, Cols = (), Index = Idx<Rows>>> LastEq<Rows, (), M>
where M::Dyn: MatIndex<Rows = usize, Cols = (), Index = usize>,

pub fn for_each(self, f: impl FnMut(<Self as MatIndex>::Item))

applies f to each element of self

pub fn for_each_with_index( self, f: impl FnMut(Idx<Rows>, <Self as MatIndex>::Item), )

applies f to each element of self, while passing the indices of the position of the current element

pub fn map<T>( self, f: impl FnMut(<Self as MatIndex>::Item) -> T, ) -> Col<T, Rows>

applies f to each element of self and collect its result into a new matrix

pub fn map_with_index<T>( self, f: impl FnMut(Idx<Rows>, <Self as MatIndex>::Item) -> T, ) -> Col<T, Rows>

applies f to each element of self and collect its result into a new matrix

Source

impl<Cols: Shape, M: MatIndex<LayoutTransform = VecLayoutTransform, Rows = (), Cols = Cols, Index = Idx<Cols>>> LastEq<(), Cols, M>
where M::Dyn: MatIndex<Rows = (), Cols = usize, Index = usize>,

pub fn for_each(self, f: impl FnMut(<Self as MatIndex>::Item))

applies f to each element of self

pub fn for_each_with_index( self, f: impl FnMut(Idx<Cols>, <Self as MatIndex>::Item), )

applies f to each element of self, while passing the indices of the position of the current element

pub fn map<T>( self, f: impl FnMut(<Self as MatIndex>::Item) -> T, ) -> Row<T, Cols>

applies f to each element of self and collect its result into a new matrix

pub fn map_with_index<T>( self, f: impl FnMut(Idx<Cols>, <Self as MatIndex>::Item) -> T, ) -> Row<T, Cols>

applies f to each element of self and collect its result into a new matrix