pub struct LastEq<Rows, Cols, Mat>(pub Mat, pub PhantomData<(Rows, Cols)>);Expand description
single matrix
Tuple Fields
0: Mat1: PhantomData<(Rows, Cols)>Implementations
Sourceimpl<Rows: Shape, Cols: Shape, M: MatIndex<LayoutTransform = MatLayoutTransform, Rows = Rows, Cols = Cols, Index = (Idx<Rows>, Idx<Cols>)>> LastEq<Rows, Cols, M>
impl<Rows: Shape, Cols: Shape, M: MatIndex<LayoutTransform = MatLayoutTransform, Rows = Rows, Cols = Cols, Index = (Idx<Rows>, Idx<Cols>)>> LastEq<Rows, Cols, M>
Sourcepub fn for_each(self, f: impl FnMut(<Self as MatIndex>::Item))
pub fn for_each(self, f: impl FnMut(<Self as MatIndex>::Item))
applies f to each element of self
Sourcepub fn for_each_with_index(
self,
f: impl FnMut(Idx<Rows>, Idx<Cols>, <Self as MatIndex>::Item),
)
pub fn for_each_with_index( self, f: impl FnMut(Idx<Rows>, Idx<Cols>, <Self as MatIndex>::Item), )
applies f to each element of self, while passing the indices of the position of the
current element
Sourcepub fn for_each_triangular_lower_with_index(
self,
diag: Diag,
f: impl FnMut(Idx<Rows>, Idx<Cols>, <Self as MatIndex>::Item),
)
pub fn for_each_triangular_lower_with_index( self, diag: Diag, f: impl FnMut(Idx<Rows>, Idx<Cols>, <Self as MatIndex>::Item), )
applies f to each element of the lower triangular half of self, while passing the
indices of the position of the current element
diag specifies whether the diagonal should be included or excluded
Sourcepub fn for_each_triangular_upper_with_index(
self,
diag: Diag,
f: impl FnMut(Idx<Rows>, Idx<Cols>, <Self as MatIndex>::Item),
)
pub fn for_each_triangular_upper_with_index( self, diag: Diag, f: impl FnMut(Idx<Rows>, Idx<Cols>, <Self as MatIndex>::Item), )
applies f to each element of the upper triangular half of self, while passing the
indices of the position of the current element
diag specifies whether the diagonal should be included or excluded
Sourcepub fn for_each_triangular_lower(
self,
diag: Diag,
f: impl FnMut(<Self as MatIndex>::Item),
)
pub fn for_each_triangular_lower( self, diag: Diag, f: impl FnMut(<Self as MatIndex>::Item), )
applies f to each element of the lower triangular half of self
diag specifies whether the diagonal should be included or excluded
Sourcepub fn for_each_triangular_upper(
self,
diag: Diag,
f: impl FnMut(<Self as MatIndex>::Item),
)
pub fn for_each_triangular_upper( self, diag: Diag, f: impl FnMut(<Self as MatIndex>::Item), )
applies f to each element of the upper triangular half of self
diag specifies whether the diagonal should be included or excluded
Sourceimpl<Rows: Shape, M: MatIndex<LayoutTransform = VecLayoutTransform, Rows = Rows, Cols = (), Index = Idx<Rows>>> LastEq<Rows, (), M>
impl<Rows: Shape, M: MatIndex<LayoutTransform = VecLayoutTransform, Rows = Rows, Cols = (), Index = Idx<Rows>>> LastEq<Rows, (), M>
Sourcepub fn for_each(self, f: impl FnMut(<Self as MatIndex>::Item))
pub fn for_each(self, f: impl FnMut(<Self as MatIndex>::Item))
applies f to each element of self
Sourcepub fn for_each_with_index(
self,
f: impl FnMut(Idx<Rows>, <Self as MatIndex>::Item),
)
pub fn for_each_with_index( self, f: impl FnMut(Idx<Rows>, <Self as MatIndex>::Item), )
applies f to each element of self, while passing the indices of the position of the
current element
Sourceimpl<Cols: Shape, M: MatIndex<LayoutTransform = VecLayoutTransform, Rows = (), Cols = Cols, Index = Idx<Cols>>> LastEq<(), Cols, M>
impl<Cols: Shape, M: MatIndex<LayoutTransform = VecLayoutTransform, Rows = (), Cols = Cols, Index = Idx<Cols>>> LastEq<(), Cols, M>
Sourcepub fn for_each(self, f: impl FnMut(<Self as MatIndex>::Item))
pub fn for_each(self, f: impl FnMut(<Self as MatIndex>::Item))
applies f to each element of self
Sourcepub fn for_each_with_index(
self,
f: impl FnMut(Idx<Cols>, <Self as MatIndex>::Item),
)
pub fn for_each_with_index( self, f: impl FnMut(Idx<Cols>, <Self as MatIndex>::Item), )
applies f to each element of self, while passing the indices of the position of the
current element