pub struct ZipEq<Rows, Cols, Head, Tail>(pub Head, pub Tail, _);Expand description
zipped matrices
Tuple Fields
0: Head1: TailImplementations
Sourceimpl<Rows: Copy + Eq + Debug, Cols: Copy + Eq + Debug, Head: MatIndex<Rows = Rows, Cols = Cols>, Tail: MatIndex<Rows = Rows, Cols = Cols>> ZipEq<Rows, Cols, Head, Tail>
single matrix view
impl<Rows: Copy + Eq + Debug, Cols: Copy + Eq + Debug, Head: MatIndex<Rows = Rows, Cols = Cols>, Tail: MatIndex<Rows = Rows, Cols = Cols>> ZipEq<Rows, Cols, Head, Tail>
single matrix view
Sourcepub fn new(head: Head, tail: Tail) -> Self
pub fn new(head: Head, tail: Tail) -> Self
creates a zip matrix, after asserting that the dimensions match
Sourcepub fn new_unchecked(head: Head, tail: Tail) -> Self
pub fn new_unchecked(head: Head, tail: Tail) -> Self
creates a zip matrix, assuming that the dimensions match
Sourceimpl<Rows: Shape, Cols: Shape, L: MatIndex<LayoutTransform = MatLayoutTransform, Rows = Rows, Cols = Cols, Index = (Idx<Rows>, Idx<Cols>)>, R: MatIndex<LayoutTransform = MatLayoutTransform, Rows = Rows, Cols = Cols, Index = (Idx<Rows>, Idx<Cols>)>> ZipEq<Rows, Cols, L, R>
impl<Rows: Shape, Cols: Shape, L: MatIndex<LayoutTransform = MatLayoutTransform, Rows = Rows, Cols = Cols, Index = (Idx<Rows>, Idx<Cols>)>, R: MatIndex<LayoutTransform = MatLayoutTransform, Rows = Rows, Cols = Cols, Index = (Idx<Rows>, Idx<Cols>)>> ZipEq<Rows, Cols, L, R>
Sourcepub fn for_each(self, f: impl FnMut(<Self as MatIndex>::Item))
pub fn for_each(self, f: impl FnMut(<Self as MatIndex>::Item))
applies f to each element of self
Sourcepub fn for_each_with_index(
self,
f: impl FnMut(Idx<Rows>, Idx<Cols>, <Self as MatIndex>::Item),
)
pub fn for_each_with_index( self, f: impl FnMut(Idx<Rows>, Idx<Cols>, <Self as MatIndex>::Item), )
applies f to each element of self, while passing the indices of the position of the
current element
Sourcepub fn for_each_triangular_lower_with_index(
self,
diag: Diag,
f: impl FnMut(Idx<Rows>, Idx<Cols>, <Self as MatIndex>::Item),
)
pub fn for_each_triangular_lower_with_index( self, diag: Diag, f: impl FnMut(Idx<Rows>, Idx<Cols>, <Self as MatIndex>::Item), )
applies f to each element of the lower triangular half of self, while passing the
indices of the position of the current element
diag specifies whether the diagonal should be included or excluded
Sourcepub fn for_each_triangular_upper_with_index(
self,
diag: Diag,
f: impl FnMut(Idx<Rows>, Idx<Cols>, <Self as MatIndex>::Item),
)
pub fn for_each_triangular_upper_with_index( self, diag: Diag, f: impl FnMut(Idx<Rows>, Idx<Cols>, <Self as MatIndex>::Item), )
applies f to each element of the upper triangular half of self, while passing the
indices of the position of the current element
diag specifies whether the diagonal should be included or excluded
Sourcepub fn for_each_triangular_lower(
self,
diag: Diag,
f: impl FnMut(<Self as MatIndex>::Item),
)
pub fn for_each_triangular_lower( self, diag: Diag, f: impl FnMut(<Self as MatIndex>::Item), )
applies f to each element of the lower triangular half of self
diag specifies whether the diagonal should be included or excluded
Sourcepub fn for_each_triangular_upper(
self,
diag: Diag,
f: impl FnMut(<Self as MatIndex>::Item),
)
pub fn for_each_triangular_upper( self, diag: Diag, f: impl FnMut(<Self as MatIndex>::Item), )
applies f to each element of the upper triangular half of self
diag specifies whether the diagonal should be included or excluded
Sourceimpl<Rows: Shape, L: MatIndex<LayoutTransform = VecLayoutTransform, Rows = Rows, Cols = (), Index = Idx<Rows>>, R: MatIndex<LayoutTransform = VecLayoutTransform, Rows = Rows, Cols = (), Index = Idx<Rows>>> ZipEq<Rows, (), L, R>
impl<Rows: Shape, L: MatIndex<LayoutTransform = VecLayoutTransform, Rows = Rows, Cols = (), Index = Idx<Rows>>, R: MatIndex<LayoutTransform = VecLayoutTransform, Rows = Rows, Cols = (), Index = Idx<Rows>>> ZipEq<Rows, (), L, R>
Sourcepub fn for_each(self, f: impl FnMut(<Self as MatIndex>::Item))
pub fn for_each(self, f: impl FnMut(<Self as MatIndex>::Item))
applies f to each element of self
Sourcepub fn for_each_with_index(
self,
f: impl FnMut(Idx<Rows>, <Self as MatIndex>::Item),
)
pub fn for_each_with_index( self, f: impl FnMut(Idx<Rows>, <Self as MatIndex>::Item), )
applies f to each element of self, while passing the indices of the position of the
current element
Sourceimpl<Cols: Shape, L: MatIndex<LayoutTransform = VecLayoutTransform, Rows = (), Cols = Cols, Index = Idx<Cols>>, R: MatIndex<LayoutTransform = VecLayoutTransform, Rows = (), Cols = Cols, Index = Idx<Cols>>> ZipEq<(), Cols, L, R>
impl<Cols: Shape, L: MatIndex<LayoutTransform = VecLayoutTransform, Rows = (), Cols = Cols, Index = Idx<Cols>>, R: MatIndex<LayoutTransform = VecLayoutTransform, Rows = (), Cols = Cols, Index = Idx<Cols>>> ZipEq<(), Cols, L, R>
Sourcepub fn for_each(self, f: impl FnMut(<Self as MatIndex>::Item))
pub fn for_each(self, f: impl FnMut(<Self as MatIndex>::Item))
applies f to each element of self
Sourcepub fn for_each_with_index(
self,
f: impl FnMut(Idx<Cols>, <Self as MatIndex>::Item),
)
pub fn for_each_with_index( self, f: impl FnMut(Idx<Cols>, <Self as MatIndex>::Item), )
applies f to each element of self, while passing the indices of the position of the
current element